Pull Request Guidelines for py-ballisticcalc
---------------------------------

Before you submit a pull request, check that it meets these guidelines:

1. If the pull request adds functionality, the docs should be updated.
2. Modify the `docs/changelog.md`, describing your changes as is specified by the
   guidelines in that document.
3. Follow the `docs/contributing.md`
4. The pull request should work for Python 3.10+ on the following platforms:
    - Windows 10 and greater
    - Linux distributions
    - OS X / macOS >= 13
5. Squash all your commits on your PR branch if the commits are not solving
   different problems, and you are committing them in the same PR. In that case,
   consider making several PRs instead.
6. Feel free to add your name as a contributor to the `docs/contributors.md` file!